(**  *)
(** {{:http://www.sfml-dev.org/documentation/2.0/classsf_1_1RenderWindow.php}
  Online documentation for the RenderWindow class} *)

type t
type window_style = [ `close | `fullscreen | `resize | `titlebar ]
type video_mode = { width : int; height : int; bitsPerPixel : int; }
type context_settings = {
  depthBits : int;
  stencilBits : int;
  antialiasingLevel : int;
  majorVersion : int;
  minorVersion : int;
}
val mode : width:int -> height:int -> bitsPerPixel:int -> video_mode
val settings :
  depthBits:int ->
  stencilBits:int ->
  antialiasingLevel:int -> version:int * int -> context_settings
external create :
  mode:video_mode ->
  title:string -> style:window_style list -> settings:context_settings -> t
  = "caml_sfRenderWindow_create"
external createFromHandle :
  handle:nativeint -> settings:context_settings -> t
  = "caml_sfRenderWindow_createFromHandle"
val make :
  ?style:window_style list ->
  ?bpp:int ->
  ?depth:int ->
  ?stencil:int ->
  ?antialiasing:int -> ?version:int * int -> int * int -> string -> t
external isOpen : t -> bool = "caml_sfRenderWindow_isOpen"
external close : t -> unit = "caml_sfRenderWindow_close"
external display : t -> unit = "caml_sfRenderWindow_display"
external destroy : t -> unit = "caml_sfRenderWindow_destroy"
external pollEvent : t -> SFEvent.t option = "caml_sfRenderWindow_pollEvent"
external waitEvent : t -> SFEvent.t = "caml_sfRenderWindow_waitEvent"
external clear : t -> SFColor.t -> unit = "caml_sfRenderWindow_clear"
external blank : t -> unit = "caml_sfRenderWindow_blank"
external getSettings : t -> context_settings
  = "caml_sfRenderWindow_getSettings"
external getSize : t -> int * int = "caml_sfRenderWindow_getSize"
external getWidth : t -> int = "caml_sfRenderWindow_getWidth"
external getHeight : t -> int = "caml_sfRenderWindow_getHeight"
external setSize : t -> width:int -> height:int -> unit
  = "caml_sfRenderWindow_setSize"
external setSize2 : t -> size:int * int -> unit
  = "caml_sfRenderWindow_setSize2"
external setMouseCursorVisible : t -> show:bool -> unit
  = "caml_sfRenderWindow_setMouseCursorVisible"
external setVisible : t -> visible:bool -> unit
  = "caml_sfRenderWindow_setVisible"
external setKeyRepeatEnabled : t -> enabled:bool -> unit
  = "caml_sfRenderWindow_setKeyRepeatEnabled"
external setActive : t -> active:bool -> unit
  = "caml_sfRenderWindow_setActive"
external drawSprite :
  t -> sprite:SFSprite.t -> ?states:SFRenderStates.t -> unit -> unit
  = "caml_sfRenderWindow_drawSprite"
external drawText :
  t -> text:SFText.t -> ?states:SFRenderStates.t -> unit -> unit
  = "caml_sfRenderWindow_drawText"
external drawShape :
  t -> shape:SFShape.t -> ?states:SFRenderStates.t -> unit -> unit
  = "caml_sfRenderWindow_drawShape"
external drawCircleShape :
  t -> circle:SFCircleShape.t -> ?states:SFRenderStates.t -> unit -> unit
  = "caml_sfRenderWindow_drawCircleShape"
external setPosition : t -> left:int -> top:int -> unit
  = "caml_sfRenderWindow_setPosition"
external setPosition2 : t -> pos:int * int -> unit
  = "caml_sfRenderWindow_setPosition2"
external setFramerateLimit : t -> limit:int -> unit
  = "caml_sfRenderWindow_setFramerateLimit"
external setView : t -> view:SFView.t -> unit = "caml_sfRenderWindow_setView"
external setVerticalSyncEnabled : t -> enabled:bool -> unit
  = "caml_sfRenderWindow_setVerticalSyncEnabled"
external setJoystickThreshold : t -> threshold:float -> unit
  = "caml_sfRenderWindow_setJoystickThreshold"
external setTitle : t -> title:string -> unit
  = "caml_sfRenderWindow_setTitle"
external pushGLStates : t -> unit = "caml_sfRenderWindow_pushGLStates"
external popGLStates : t -> unit = "caml_sfRenderWindow_popGLStates"
external resetGLStates : t -> unit = "caml_sfRenderWindow_resetGLStates"
external getView : t -> SFView.t = "caml_sfRenderWindow_getView"
external capture : t -> SFImage.t = "caml_sfRenderWindow_capture"
external getMousePosition : relativeTo:t -> int * int
  = "caml_sfRenderWindow_getMousePosition"
external setMousePosition : relativeTo:t -> int * int -> unit
  = "caml_sfRenderWindow_setMousePosition"
