(**  *)
(** {{:http://www.sfml-dev.org/documentation/2.0/classsf_1_1Window.php}
  Online documentation for the Window class} *)

type t
type window_style =
    [ `close | `default_style | `fullscreen | `resize | `titlebar ]
type video_mode = { width : int; height : int; bitsPerPixel : int; }
type context_settings = {
  depthBits : int;
  stencilBits : int;
  antialiasingLevel : int;
  majorVersion : int;
  minorVersion : int;
}
val mode : width:int -> height:int -> ?bpp:int -> unit -> video_mode
val settings :
  ?depth:int ->
  ?stencil:int ->
  ?antialiasing:int -> ?version:int * int -> unit -> context_settings
external create :
  mode:video_mode ->
  title:string -> style:window_style list -> settings:context_settings -> t
  = "caml_sfWindow_create"
external createFromHandle :
  handle:nativeint -> settings:context_settings -> t
  = "caml_sfWindow_createFromHandle"
val make :
  ?style:window_style list ->
  ?bpp:int ->
  ?depth:int ->
  ?stencil:int ->
  ?antialiasing:int -> ?version:int * int -> int * int -> string -> t
external isOpen : t -> bool = "caml_sfWindow_isOpen"
external close : t -> unit = "caml_sfWindow_close"
external display : t -> unit = "caml_sfWindow_display"
external destroy : t -> unit = "caml_sfWindow_destroy"
external pollEvent : t -> SFEvent.t option = "caml_sfWindow_pollEvent"
external waitEvent : t -> SFEvent.t = "caml_sfWindow_waitEvent"
external getSize : t -> int * int = "caml_sfWindow_getSize"
external getWidth : t -> int = "caml_sfWindow_getWidth"
external getHeight : t -> int = "caml_sfWindow_getHeight"
external setSize : t -> size:int * int -> unit = "caml_sfWindow_setSize"
external setSize2 : t -> width:int -> height:int -> unit
  = "caml_sfWindow_setSize2"
external setPosition : t -> pos:int * int -> unit
  = "caml_sfWindow_setPosition"
external setPosition2 : t -> left:int -> top:int -> unit
  = "caml_sfWindow_setPosition2"
external getPosition : t -> int * int = "caml_sfWindow_getPosition"
external setTitle : t -> title:string -> unit = "caml_sfWindow_setTitle"
external setActive : t -> active:bool -> bool = "caml_sfWindow_setActive"
external setVisible : t -> visible:bool -> unit = "caml_sfWindow_setVisible"
external setMouseCursorVisible : t -> visible:bool -> unit
  = "caml_sfWindow_setMouseCursorVisible"
external setKeyRepeatEnabled : t -> enabled:bool -> unit
  = "caml_sfWindow_setKeyRepeatEnabled"
external setJoystickThreshold : t -> threshold:float -> unit
  = "caml_sfWindow_setJoystickThreshold"
external setFramerateLimit : t -> limit:int -> unit
  = "caml_sfWindow_setFramerateLimit"
external setVerticalSyncEnabled : t -> enabled:bool -> unit
  = "caml_sfWindow_setVerticalSyncEnabled"
external getMousePosition : relativeTo:t -> int * int
  = "caml_sfWindow_getMousePosition"
external setMousePosition : relativeTo:t -> int * int -> unit
  = "caml_sfWindow_setMousePosition"
